@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2017-2020 Rumma & Ko Ltd
+# Copyright 2017-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
@@ -346,7 +346,7 @@ class PrintableInvoicesByJournal(PrintableByJournal, Invoices):
 class ItemsByInvoice(ItemsByVoucher):
     model = 'ana.InvoiceItem'
     column_names = "account title ana_account vat_class total_base total_vat total_incl *"
-    display_mode = 'grid'
+    display_mode_main = 'grid'
 
 
 
