@@ -1,5 +1,7 @@
 # Copyright 2008-2017 Rumma & Ko Ltd
-"""Functionality for managing VAT declarations.
+"""National VAT plugin for Belgian "simple" VAT declarations.
+
+See :doc:`/plugins/bevats`.
 
 .. autosummary::
    :toctree:
@@ -26,10 +28,8 @@ class Plugin(ad.Plugin):
     # def before_analyze(self):
     #     super(Plugin, self).before_analyze()
     #     import_module(self.country_module)
-    
+
     def setup_explorer_menu(self, site, user_type, m):
         m = m.add_menu("vat", site.plugins.vat.verbose_name)
         m.add_action('bevats.Declarations')
         m.add_action('bevats.DeclarationFields')
-
-
