@@ -21,10 +21,11 @@ from lino import mixins
 from lino.api import dd, rt, _, pgettext
 
 from lino.core.site import html2text
-from lino.mixins import Referrable
+from lino.mixins import Referrable, Draggable
 # from lino.mixins.periods import DateRangeObservable
 from lino.utils.quantities import Duration
 from lino.modlib.checkdata.choicelists import Checker
+from lino.modlib.gfks.mixins import Controllable
 from lino.modlib.notify.api import send_notification
 from lino.modlib.printing.mixins import TypedPrintable
 from lino.modlib.printing.mixins import Printable
@@ -321,6 +322,19 @@ class EventPolicy(mixins.BabelNamed, RecurrenceSet):
 
 
 
+# class AutomaticSeries(RecurrenceSet, EventGenerator):
+class EventRepeater(Controllable, RecurrenceSet, EventGenerator):
+
+    class Meta:
+        app_label = 'cal'
+        verbose_name = _("Event repeater")
+        verbose_name_plural = _("Event repeaters")
+        abstract = dd.is_abstract_model(__name__, 'EventRepeater')
+
+    def change_event_attribute(self, attr, value):
+        pass
+
+
 class RecurrentEvent(mixins.BabelNamed, RecurrenceSet, EventGenerator,
                      UserAuthored):
     class Meta:
@@ -393,7 +407,7 @@ class ExtAllDayField(dd.VirtualField):
 
 class Event(
     Component, Ended, Assignable, TypedPrintable, Mailable, Postable,
-    Publishable, GoogleCalendarEventSynchronized):
+    Publishable, GoogleCalendarEventSynchronized, Draggable, Controllable):
 
     class Meta:
         app_label = 'cal'
@@ -424,12 +438,25 @@ class Event(
     notify_unit = NotifyBeforeUnits.field(default='minutes')
     notified = models.BooleanField(default=False)
 
+    repeater = models.ForeignKey('cal.EventRepeater', on_delete=models.SET_NULL, null=True, blank=True)
+
     move_next = MoveEntryNext()
 
     show_conflicting = dd.ShowSlaveTable(ConflictingEvents)
     allow_merge_action = False
 
 
+    def on_dropped(self, ar, **kw):
+        start_date = datetime.datetime.fromisoformat(ar.rqdata.get('start_date')).date()
+        td = start_date - self.start_date
+        self.start_date += td
+        if self.end_date:
+            self.end_date += td
+        self.full_clean()
+        self.save()
+        ar.success(refresh=True)
+
+
     @classmethod
     def setup_parameters(cls, params):
         super(Event, cls).setup_parameters(params)
@@ -757,6 +784,11 @@ class Event(
         super(Event, self).before_ui_save(ar, cw)
 
     def on_create(self, ar):
+        if self.repeater is None:
+            repeater = rt.models.cal.EventRepeater()
+            repeater.full_clean()
+            repeater.save()
+            self.repeater = repeater
         if self.event_type is None:
             # print("20200513", ar.user)
             self.event_type = ar.get_user().event_type or \
