@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2017 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Desktop UI for this plugin.
@@ -21,11 +21,11 @@ from lino.api import dd, rt, _
 #     DeploymentsByMilestone
 #     """
 #     left_box = """
-#     site project 
+#     site project
 #     id label closed
 #     # expected reached changes_since printed
 #     """
-    
+
 # class Milestones(dd.Table):
 #     """
 #     .. attribute:: show_closed
@@ -85,7 +85,7 @@ from lino.api import dd, rt, _
 #         if ar.master_instance is not None:
 #             kw.update(project=ar.master_instance.project)
 #         return kw
-    
+
 
 class Deployments(dd.Table):
     model = 'deploy.Deployment'
@@ -131,13 +131,13 @@ class DeploymentsByMilestone(Deployments):
     ticket
     remark
     """, window_size=(60, 15))
-    
+
 
 
 # class DeploymentsByProject(DeploymentsByMilestone):
 #     master = 'tickets.Project'
 #     master_key = None
-#     display_mode = "html"
+#     display_mode_main = "html"
 
 #     @classmethod
 #     def get_filter_kw(self, ar, **kw):
@@ -146,12 +146,12 @@ class DeploymentsByMilestone(Deployments):
 #         if ar.master_instance:
 #             kw.update(milestone__project=ar.master_instance)
 #         return kw
-    
+
 
 # class DeploymentsByCompetence(DeploymentsByProject):
 #     master = 'tickets.Competence'
 #     master_key = None
-#     display_mode = "html"
+#     display_mode_main = "html"
 
 #     @classmethod
 #     def get_filter_kw(self, ar, **kw):
@@ -161,7 +161,7 @@ class DeploymentsByMilestone(Deployments):
 #         if mi and mi.project:
 #             kw.update(milestone__project=mi.project)
 #         return kw
-    
+
 
 class DeploymentsByTicket(Deployments):
     order_by = ['-milestone__end_date']
@@ -172,8 +172,8 @@ class DeploymentsByTicket(Deployments):
     milestone wish_type
     remark
     """, window_size=(60, 15))
-    
-    display_mode = 'summary'
+
+    display_mode_main = 'summary'
     stay_in_grid = True
 
     @classmethod
@@ -204,6 +204,3 @@ class DeploymentsByTicket(Deployments):
             html.append(btn)
 
         return ar.html_text(ar.parse_memo(tostring(html)))
-
-
-    
