@@ -105,7 +105,7 @@ class LinksByHuman(Links):
     required_roles = dd.login_required(ContactsUser)
     master = config.person_model
     column_names = 'parent type_as_parent:10 child'
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
     addable_link_types = (
         LinkTypes.parent, LinkTypes.adoptive_parent,
