@@ -3,7 +3,7 @@
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This is Lino's standard plugin for General Ledger.
-See :doc:`/specs/ledger`.
+See :doc:`/plugins/ledger`.
 
 .. autosummary::
     :toctree:
