@@ -63,7 +63,7 @@ class Journals(dd.Table):
 class JournalsOverview(Journals):
     required_roles = dd.login_required(LedgerUser)
     column_names = "description num_vouchers this_year this_month state_draft warnings *"
-    display_mode = "summary"
+    display_mode_main = "summary"
     editable = False
 
 
@@ -525,7 +525,7 @@ class AccountBalances(dd.Table):
     required_roles = dd.login_required(AccountingReader)
     auto_fit_column_widths = True
     column_names = "description old_d old_c empty_column:1 during_d during_c empty_column:1 new_d new_c"
-    display_mode = 'html'
+    display_mode_main = 'html'
     abstract = True
     params_panel_hidden = False
     use_as_default_table = False
@@ -711,7 +711,7 @@ class DebtorsCreditors(dd.VirtualTable):
     required_roles = dd.login_required(AccountingReader)
     auto_fit_column_widths = True
     column_names = "age due_date partner partner_id balance vouchers"
-    display_mode = 'html'
+    display_mode_main = 'html'
     abstract = True
 
     parameters = mixins.Today()
@@ -1025,7 +1025,7 @@ class MovementsByVoucher(Movements):
     column_names = 'account project partner debit credit match_link cleared *'
     sum_text_column = 3
     # auto_fit_column_widths = True
-    display_mode = "html"
+    display_mode_main = "html"
     order_by = dd.plugins.ledger.remove_dummy(
         'seqno', 'value_date', 'account__ref', 'partner', 'project', 'id')
 
@@ -1034,8 +1034,8 @@ class MovementsByPartner(Movements):
     editable = True
     allow_create = False
     master_key = 'partner'
-    # display_mode = "html"
-    display_mode = "summary"
+    # display_mode_main = "html"
+    display_mode_main = "summary"
     # auto_fit_column_widths = True
     # order_by = ['-value_date', 'voucher__id', 'account__ref']
     order_by = dd.plugins.ledger.remove_dummy(
@@ -1114,7 +1114,7 @@ class MovementsByProject(MovementsByPartner):
     column_names = 'value_date voucher_link description \
     debit credit match_link cleared *'
     master_key = 'project'
-    display_mode = "html"
+    display_mode_main = "html"
     order_by = ['-value_date', 'partner', 'id']
 
 
@@ -1144,7 +1144,7 @@ class MovementsByAccount(Movements):
     debit credit match_link *'
     # order_by = ['-value_date']
     # auto_fit_column_widths = True
-    display_mode = "html"
+    display_mode_main = "html"
     # order_by = ['-value_date', 'account__ref', 'project', 'id']
     order_by = dd.plugins.ledger.remove_dummy(
         '-value_date', 'partner__name', 'project', 'id')
