@@ -25,12 +25,14 @@ from lino.mixins.periods import DateRange
 from lino_xl.lib.excerpts.mixins import Certifiable
 from lino_xl.lib.excerpts.mixins import ExcerptTitle
 from lino.modlib.users.mixins import UserAuthored
+from lino.modlib.uploads.mixins import UploadController
 from lino.modlib.printing.mixins import Printable
 # from lino.modlib.printing.utils import PrintableObject
 # from lino_xl.lib.cal.mixins import Reservation
 from lino_xl.lib.cal.choicelists import Recurrencies
 from lino_xl.lib.cal.utils import day_and_month
 from lino_xl.lib.cal.mixins import RecurrenceSet, EventGenerator
+from lino_xl.lib.invoicing.mixins import InvoiceGenerator, Periodicities
 from lino_xl.lib.contacts.mixins import ContactRelated
 from lino_xl.lib.ledger.models import RegistrableVoucher
 from lino_xl.lib.ledger.mixins import SequencedVoucherItem
@@ -51,13 +53,17 @@ except AttributeError:
     worker_model = 'foo.Bar'
     worker_name_fields = 'foo bar'
 
-from lino.modlib.uploads.mixins import UploadController
 
 #
 # class Order(SalesDocument, UserAuthored, UploadController, RecurrenceSet, EventGenerator, Duplicable):
 # class Order(SalesDocument, Voucher, RecurrenceSet, EventGenerator, Duplicable):
 # class Order(Registrable, Certifiable, Voucher, RecurrenceSet, EventGenerator, Duplicable, ProjectRelated):
-class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Duplicable, ProjectRelated):
+class Order(
+    Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator,
+    Duplicable, ProjectRelated, ContactRelated, InvoiceGenerator):
+
+    # Voucher.voucher_date : date of signature / offer
+    # Voucher.entry_date : when agreement starts
 
     class Meta:
         app_label = 'orders'
@@ -66,7 +72,11 @@ class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Dupl
         verbose_name_plural = _('Orders')
 
     hide_editable_number = False
-    quick_search_fields = "subject project__name"
+
+    if settings.SITE.project_model is None:
+        quick_search_fields = "subject"
+    else:
+        quick_search_fields = "subject project__name"
 
     state = OrderStates.field(default='draft')
 
@@ -76,11 +86,19 @@ class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Dupl
     #     related_name="%(app_label)s_%(class)s_set_by_client",
     #     blank=True, null=True)
     #
-    invoice_recipient = dd.ForeignKey(
-        'contacts.Partner',
-        verbose_name=_("Invoice recipient"),
-        related_name='orders_by_recipient',
-        blank=True, null=True)
+
+    # 20210731
+    # invoice_recipient = dd.ForeignKey(
+    #     'contacts.Partner',
+    #     verbose_name=_("Invoice recipient"),
+    #     related_name='orders_by_recipient',
+    #     blank=True, null=True)
+    #
+    # partner = dd.ForeignKey(
+    #     'contacts.Partner',
+    #     verbose_name=_("Invoice recipient"),
+    #     blank=True, null=True)
+    #     # related_name='orders_by_recipient',
 
     subject = models.CharField(_("Our reference"), max_length=200, blank=True)
     # site_field_name = 'room'
@@ -97,6 +115,9 @@ class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Dupl
         verbose_name=_("Generate events until"))
     # order_state = OrderStates.field(default='draft')
 
+    # subscription_type = dd.ForeignKey('invoicing.SubscriptionType')
+    invoicing_periodicity = Periodicities.field(blank=True, null=True)
+
     # quick_search_fields = 'name'
 
     # max_places = models.PositiveIntegerField(
@@ -114,6 +135,29 @@ class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Dupl
     #     build_method='weasy2html',
     #     label=format_lazy(u"{}{}",_("Presence sheet"), _(" (HTML)")))
 
+    # def get_invoicing_area(self):
+    #     Area = rt.models.invoicing.Area
+    #     try:
+    #         return Area.objects.get(journal=self.journal)
+    #     except Area.DoesNotExist:
+    #         raise Warning(_("No invoicing area configured for {}").format(self.journal))
+
+    # 20210731
+    # def get_invoiceable_partner(self):
+    #     if self.invoice_recipient is not None:
+    #         return self.invoice_recipient
+    #     if self.project_id:
+    #         return self.project.get_invoiceable_partner()
+    #
+    # def get_partner(self):
+    #     if self.invoice_recipient is not None:
+    #         return self.invoice_recipient
+    #     if self.project_id is not None:
+    #         return self.project.get_partner()
+
+    # def get_invoice_recipient(self):
+    #     return self.invoice_recipient
+
     def get_worker_choices(self):
         worker = dd.resolve_model(worker_model)
         return worker.objects.all()
@@ -121,6 +165,20 @@ class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Dupl
     def full_clean(self, *args, **kwargs):
         if self.entry_date is None:
             self.entry_date = dd.today()
+        if self.partner is None:
+            # e.g. in Presto the project is a presto.Client (subclass of
+            # contacts.Person), in Noi it is a tickets.Site
+            p = self.project
+            if isinstance(p, ContactRelated):
+                self.company = p.company
+                self.contact_person = p.contact_person
+                self.contact_role = p.contact_role
+            elif isinstance(p, rt.models.contacts.Company):
+                self.company = p
+            elif isinstance(p, rt.models.contacts.Person):
+                self.contact_person = p
+        if self.partner is None:
+            raise Warning(_("Either company or person must be given."))
         super(Order, self).full_clean(*args, **kwargs)
 
     # @dd.displayfield(_("Print"))
@@ -141,12 +199,6 @@ class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Dupl
     def update_cal_until(self):
         return self.max_date
 
-    def get_partner(self):
-        if self.invoice_recipient is not None:
-            return self.invoice_recipient
-        if self.project is not None:
-            return self.project.get_partner()
-
     def get_wanted_movements(self):
         return []
 
@@ -250,6 +302,99 @@ class Order(Certifiable, RegistrableVoucher, RecurrenceSet, EventGenerator, Dupl
         return rt.models.orders.EnrolmentsByOrder.request(
             self, param_values=pv)
 
+    @classmethod
+    def get_generators_for_plan(cls, plan, partner=None):
+        # pre-select all Event objects that potentially will generate
+        # an invoice.
+        qs = super(Order, cls).get_generators_for_plan(plan, partner)
+
+        if plan.area is not None:
+            qs = qs.filter(journal__invoicing_area=plan.area)
+
+        if plan.order is None:
+            qs = qs.exclude(state=OrderStates.cancelled)
+            qs = qs.exclude(state=OrderStates.draft)
+        elif issubclass(dd.plugins.invoicing.order_model, cls):
+            qs = qs.filter(id=plan.order.id)
+        else:
+            raise Exception("20210731 {}".format(dd.plugins.invoicing.order_model))
+
+        # qs = cls.objects.all()
+        # dd.logger.info("20210727 c %s", qs)
+
+        # if plan.order is not None:
+        #     qs = qs.filter(**gfk2lookup(cls.owner, plan.order))
+
+        if partner is None:
+            partner = plan.partner
+
+        if partner is not None:
+            fldname = cls.get_partner_filter_field(partner)
+            qs = cls.filter_by_invoice_recipient(qs, partner, fldname)
+
+            # qs = cls.add_partner_filter(qs, partner)
+            # if False:
+            #     q1 = models.Q(
+            #         company__salesrule__invoice_recipient__isnull=True, company__pk=partner.pk)
+            #     q2 = models.Q(company__salesrule__invoice_recipient=partner)
+            #     flt1 = models.Q(models.Q(q1 | q2), company__isnull=False)
+            #     q3 = models.Q(
+            #         contact_person__salesrule__invoice_recipient__isnull=True, contact_person__pk=partner.pk)
+            #     q4 = models.Q(contact_person__salesrule__invoice_recipient=partner)
+            #     flt2 = models.Q(models.Q(q3 | q4), company__isnull=True)
+            #     qs = qs.filter(flt1 | flt2)
+            # else:
+                # if isinstance(partner, rt.models.contacts.Company):
+                #     qs = qs.filter(company=partner)
+                # elif isinstance(partner, rt.models.contacts.Person):
+                #     qs = qs.filter(contact_person=partner)
+                # qs = qs.filter(
+                #     models.Q(company=partner) | models.Q(contact_person=partner))
+
+        # dd.logger.info("20200518 %s (%d rows)", qs.query, qs.count())
+        return qs.order_by('id')
+
+    def get_invoice_items(self, info, invoice, ar):
+        # dd.logger.info("20181116a %s", self)
+        for i in super(Order, self).get_invoice_items(info, invoice, ar):
+            # print("20210731 a", i)
+            yield i
+        if info.number_of_events is None and info.asset_to_buy is not None:
+            for oi in self.items.all():
+                kwargs = dict(
+                    # 20210804 invoiceable=self,
+                    product=oi.product,
+                    unit_price=oi.unit_price,
+                    qty=oi.qty)
+                i = invoice.add_voucher_item(**kwargs)
+                i.product_changed(ar)
+                # i.reset_totals(ar)
+                if i.total_incl is None:
+                    print("20210731 invoice item without amount:", i.__class__, i)
+                yield i
+
+    def get_invoiceable_product(self, max_date=None):
+        return None
+
+    def get_invoiceable_qty(self):
+        return self.default_invoiceable_qty
+
+    def get_invoicing_pass_type(self, product=None):
+        if product is not None:
+            return product.tariff
+        return None
+
+    def get_invoiceable_end_date(self):
+        return self.max_date
+
+    def get_invoiceable_start_date(self, max_date):
+        return self.entry_date
+
+    def get_invoicing_periodicity(self, product):
+        return self.invoicing_periodicity
+
+
+
     # @dd.virtualfield(dd.HtmlBox(_("Presences")))
     # def presences_box(self, ar):
     #     # not finished
@@ -361,7 +506,7 @@ def setup_memo_commands(sender=None, **kwargs):
 
     Order = sender.models.orders.Order
 
-    def cmd(parser, s):
+    def cmd(parser, s, cmdname, usages):
 
         pk = s
         txt = None
@@ -401,11 +546,10 @@ class OrderItem(SequencedVoucherItem):
     # title = models.CharField(_("Heading"), max_length=200, blank=True)
     product = dd.ForeignKey('products.Product', blank=True, null=True)
     qty = dd.QuantityField(_("Quantity"), blank=True, null=True)
-    # unit_price = dd.PriceField(_("Unit price"), blank=True, null=True)
+    unit_price = dd.PriceField(_("Unit price"), blank=True, null=True)
     remark = models.CharField(_("Remark"), max_length=200, blank=True)
 
 
-
 dd.inject_field('ledger.Journal', 'room', dd.ForeignKey('cal.Room', blank=True, null=True))
 
 from .ui import *
