@@ -121,7 +121,7 @@ class ContactDetailsByPartner(ContactDetails):
     stay_in_grid = True
     window_size = (80, 20)
 
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
     @classmethod
     def get_table_summary(self, obj, ar):
