@@ -380,7 +380,7 @@ class ResponsesByPoll(Responses):
 class ResponsesByPartner(Responses):
     master_key = 'partner'
     column_names = 'date user state remark *'
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
     @classmethod
     def get_table_summary(self, obj, ar):
@@ -593,7 +593,7 @@ class AnswersByResponseEditor(AnswersByResponseBase):
     column_names = 'question:40 answer_buttons:30 remark:20 *'
     variable_row_height = True
     auto_fit_column_widths = True
-    display_mode = 'summary'
+    display_mode_main = 'summary'
     # workflow_state_field = 'state'
 
     remark = AnswerRemarkField()
@@ -718,7 +718,7 @@ class AnswersByResponseEditor(AnswersByResponseBase):
 
 
 class AnswersByResponsePrint(AnswersByResponseBase):
-    display_mode = "summary"
+    display_mode_main = "summary"
     column_names = 'question *'
 
     @classmethod
