@@ -46,4 +46,4 @@ class Thirds(dd.Table):
 class ThirdsByController(Thirds):
     master_key = 'owner'
     column_names = "seqno person company id *"
-    display_mode = 'summary'
+    display_mode_main = 'summary'
