@@ -3,7 +3,7 @@
 """
 Adds functionality for managing tickets.
 
-See :doc:`/specs/noi/tickets`.
+See :doc:`/specs/tickets`.
 
 .. autosummary::
    :toctree:
