@@ -1,9 +1,9 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2019 Rumma & Ko
+# Copyright 2013-2021 Rumma & Ko
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
-"""See :doc:`/specs/vat`.
+"""See :doc:`/plugins/vat`.
 
 .. autosummary::
    :toctree:
@@ -13,9 +13,7 @@
 
 """
 
-from django.utils.translation import gettext_lazy as _
-from lino.api import ad
-import six
+from lino.api import ad, _
 
 class Plugin(ad.Plugin):
     """The :class:`Plugin <lino.core.plugin.Plugin>` object for this
@@ -27,28 +25,12 @@ class Plugin(ad.Plugin):
 
     needs_plugins = ['lino.modlib.checkdata', 'lino_xl.lib.excerpts']
 
-    eu_country_codes = """AT BE BG CY CZ DK DE EE ES FI FR GB GR HU HR IE IT LV
-    LT LU MT NL PO PT RO SE SI SK"""
+    eu_country_codes = {"AT", "BE", "BG", "CY", "CZ", "DK", "DE", "EE", "ES",
+    "FI", "FR", "GR", "HU", "HR", "IE", "IT", "LV", "LT", "LU", "MT", "NL",
+    "PO", "PT", "RO", "SE", "SI", "SK"}
 
-    """A space-separated list of ISO codes that are to be considered part of
-    the EU. This is used to define the VAT area of a partner, which in turn
-    influences the available VAT regimes.  See
-    :class:`lino_xl.lib.vat.VatAreas`.
-
-    When a member state leaves or joins the EU (and you have partners there),
-    you can either update your Lino (we plan to keep this list up to date), or
-    you can change it locally.
-
-    At site startup this is converted from a string to a set. Duplicate codes
-    are ignored. For example so in your :attr:`layouts_module
-    <lino.core.site.Site.layouts_module>` you may write code like this::
-
-        if brexit:
-            dd.plugins.vat.eu_country_codes.remove("GB")
-
-    The :attr:`isocode <lino_xl.lib.countries.Country.isocode>` fields in your
-    :class:`countries.Countries <lino_xl.lib.countries.Countries>` table must
-    match the codes specified here.
+    """A set of ISO codes that are to be considered part of the EU. See
+    :ref:`dg.plugins.vat.eu_country_codes`.
 
     """
 
@@ -67,15 +49,15 @@ class Plugin(ad.Plugin):
     """
 
     declaration_plugin = None
-    """The plugin to use as your :term:`national declaration module`.
+    """The plugin to use as your :term:`national VAT module`.
 
-    Available VAT declaration plugins are:
+    Available modules are:
     :mod:`lino_xl.lib.bevat`,
     :mod:`lino_xl.lib.bevats` and
     :mod:`lino_xl.lib.eevat`.
 
-    This can remain `None` e.g. in applicatons that use the ledger plugin for
-    orders or invoicing, but don't care about general accounting functionality.
+    This may remain `None`, e.g. in applicatons that use the ledger plugin for
+    orders or invoicing without caring about general accounting functionality.
 
     """
 
@@ -83,6 +65,11 @@ class Plugin(ad.Plugin):
     """Whether item prices in trade documents are meant VAT included.
     """
 
+    use_online_check = False
+    """Whether to verify :term:`VAT numbers <VAT number>` online via `VIES
+    <https://ec.europa.eu/taxation_customs/vies/>`__.
+    """
+
     def get_vat_class(self, tt, item):
         """Return the VAT class to be used for given trade type and given
         invoice item. Return value must be an item of
@@ -111,12 +98,12 @@ class Plugin(ad.Plugin):
 
     def on_site_startup(self, site):
         vat = site.modules.vat
-        if isinstance(self.eu_country_codes, six.string_types):
-            self.eu_country_codes = set(self.eu_country_codes.split())
-        if isinstance(self.default_vat_regime, six.string_types):
+        # if isinstance(self.eu_country_codes, str):
+        #     self.eu_country_codes = set(self.eu_country_codes.split())
+        if isinstance(self.default_vat_regime, str):
             self.default_vat_regime = vat.VatRegimes.get_by_name(
                 self.default_vat_regime)
-        if isinstance(self.default_vat_class, six.string_types):
+        if isinstance(self.default_vat_class, str):
             self.default_vat_class = vat.VatClasses.get_by_name(
                 self.default_vat_class)
 
@@ -144,3 +131,7 @@ class Plugin(ad.Plugin):
         m.add_action('vat.Invoices')
         m.add_action('vat.VatRules')
         # m.add_action('vat.InvoiceItems')
+
+    def get_requirements(self, site):
+        if self.use_online_check:
+            yield 'pyvat'
