@@ -1,12 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 # $ python setup.py test -s tests.test_packages
 
 
 SETUP_INFO = dict(
     name='lino-xl',
-    version='22.1.0',
+    version='22.3.0',
     install_requires=['lino'],  # odfpy dependency now in lino_xl.lib.appypod
     tests_require=[],
     description="The Lino Extensions Library",
@@ -48,6 +48,7 @@ lino_xl.lib.appypod
 lino_xl.lib.beid
 lino_xl.lib.blogs
 lino_xl.lib.blogs.fixtures
+lino_xl.lib.bnid
 lino_xl.lib.boards
 lino_xl.lib.github
 lino_xl.lib.groups
@@ -107,6 +108,7 @@ lino_xl.lib.caldav
 lino_xl.lib.mailbox
 lino_xl.lib.mailbox.fixtures
 lino_xl.lib.meetings
+lino_xl.lib.measurements
 lino_xl.lib.notes
 lino_xl.lib.notes.fixtures
 lino_xl.lib.outbox
